Selection
:::::::::

.. toctree::
   :caption: Selection
   :maxdepth: 2

   BooleanValuesandBooleanExpressions.rst
   Logicaloperators.rst
   PrecedenceofOperators.rst
   ConditionalExecutionBinarySelection.rst
   OmittingtheelseClauseUnarySelection.rst
   Nestedconditionals.rst
   Chainedconditionals.rst
   BooleanFunctions.rst
   Glossary.rst
   Exercises.rst
